@@ -7,6 +7,7 @@ mod tests {
     use super::*;
     use mockito::{mock, Matcher};
     use float_cmp::*;
+    use binance::account::OrderSide;
     use binance::futures::model::Transaction;
 
     #[test]
@@ -117,4 +118,45 @@ mod tests {
 
     }
 
+    #[test]
+    fn custom_order() {
+        let mock_custom_order = mock("POST", "/fapi/v1/order")
+            .with_header("content-type", "application/json;charset=UTF-8")
+            .match_query(Matcher::Regex("closePosition=TRUE&recvWindow=1234&side=SELL&stopPrice=7.4&symbol=SRMUSDT&timestamp=\\d+&type=STOP_MARKET".into()))
+            .with_body_from_file("tests/mocks/futures/account/stop_market_close_position_sell.json")
+            .create();
+
+        let config = Config::default()
+            .set_futures_rest_api_endpoint(mockito::server_url())
+            .set_recv_window(1234);
+        let account: FuturesAccount = Binance::new_with_config(None, None, &config);
+        let _ = env_logger::try_init();
+        let custom_order = CustomOrderRequest{
+            symbol: "SRMUSDT".into(),
+            side: OrderSide::Sell,
+            position_side: None,
+            order_type: OrderType::StopMarket,
+            time_in_force: None,
+            qty: None,
+            reduce_only: None,
+            price: None,
+            stop_price: Some(7.4.into()),
+            close_position: Some(true),
+            activation_price: None,
+            callback_rate: None,
+            working_type: None,
+            price_protect: None,
+        };
+        let transaction: Transaction = account.custom_order(custom_order).unwrap();
+
+        mock_custom_order.assert();
+
+        assert_eq!(transaction.symbol, "SRMUSDT");
+        assert_eq!(transaction.side, "SELL");
+        assert_eq!(transaction.orig_type, "STOP_MARKET");
+        assert_eq!(transaction.close_position, true);
+        assert!(approx_eq!(f64, transaction.stop_price, 7.4, ulps = 2));
+
+    }
+
 }
\ No newline at end of file
